@@ -1,32 +1,19 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "importimapsettingwizard.h"
-#include "importimapsettingsearchpage.h"
-#include "importimapsettingnofoundpage.h"
-#include "importimapsettingfinishpage.h"
-#include "importimapsettingprogresspage.h"
 #include "checks/importimapsettingsakonadicheckjob.h"
 #include "checks/importimapsettingsthunderbirdcheckjob.h"
+#include "importimapsettingfinishpage.h"
+#include "importimapsettingnofoundpage.h"
+#include "importimapsettingprogresspage.h"
+#include "importimapsettingsearchpage.h"
 
-#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KSharedConfig>
 #include <PimCommon/PimUtil>
 #include <importwizard/checks/importimapsettingsakonadipassword.h>
@@ -71,14 +58,14 @@ ImportImapSettingWizard::~ImportImapSettingWizard()
 void ImportImapSettingWizard::initializeWizard()
 {
     bool hasSettingToImport = false;
-    auto *thjob = new ImportImapSettingsThunderbirdCheckJob(this);
+    auto thjob = new ImportImapSettingsThunderbirdCheckJob(this);
     if (thjob->settingsCanBeImported()) {
         mListCheckJob.insert(thjob->name(), thjob);
         hasSettingToImport = true;
     } else {
         delete thjob;
     }
-    auto *akonadiJob = new ImportImapSettingsAkonadiCheckJob(this);
+    auto akonadiJob = new ImportImapSettingsAkonadiCheckJob(this);
     akonadiJob->setImapSettingsPassword(new ImportImapSettingsAkonadiPassword);
     if (akonadiJob->settingsCanBeImported()) {
         mListCheckJob.insert(akonadiJob->name(), akonadiJob);
@@ -88,7 +75,7 @@ void ImportImapSettingWizard::initializeWizard()
     }
 
     if (hasSettingToImport) {
-        //Initialize list
+        // Initialize list
         mSearchPage->setProgramList(mListCheckJob.keys());
         setAppropriate(mNoFoundPageItem, false);
         setAppropriate(mSearchPageItem, false);
@@ -116,12 +103,12 @@ void ImportImapSettingWizard::next()
     if (currentPage() == mSearchPageItem) {
         const QStringList programs = mSearchPage->selectedPrograms();
         if (programs.isEmpty()) {
-            //Go to end
+            // Go to end
             setAppropriate(mProgressPageItem, false);
         } else {
             mProgressPage->setListCheckJob(mListCheckJob);
             mProgressPage->setSelectedPrograms(programs);
-            //Start importation
+            // Start importation
             mProgressPage->start();
         }
     }
