@@ -1,42 +1,29 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "sieveeditorconfiguredialog.h"
 #include "serversievelistwidget.h"
 #include "sieveeditorconfigureserverwidget.h"
-#include <PimCommon/ConfigureImmutableWidgetUtils>
 #include "sieveeditorglobalconfig.h"
+#include <PimCommon/ConfigureImmutableWidgetUtils>
 
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
-#include <KUserFeedback/Provider>
 #include <KUserFeedback/FeedbackConfigWidget>
+#include <KUserFeedback/Provider>
 #endif
 
 #include <KLocalizedString>
 #include <KSharedConfig>
 
-#include <QVBoxLayout>
-#include <QCheckBox>
 #include <KConfigGroup>
+#include <QCheckBox>
 #include <QDialogButtonBox>
 #include <QPushButton>
+#include <QVBoxLayout>
 
 SieveEditorConfigureDialog::SieveEditorConfigureDialog(QWidget *parent)
     : KPageDialog(parent)
@@ -44,26 +31,23 @@ SieveEditorConfigureDialog::SieveEditorConfigureDialog(QWidget *parent)
     setWindowTitle(i18nc("@title:window", "Configure"));
     setFaceType(KPageDialog::List);
 
-    buttonBox()->setStandardButtons(QDialogButtonBox::Ok| QDialogButtonBox::Cancel);
+    buttonBox()->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
 
     connect(buttonBox(), &QDialogButtonBox::accepted, this, &SieveEditorConfigureDialog::accept);
     connect(buttonBox(), &QDialogButtonBox::rejected, this, &SieveEditorConfigureDialog::reject);
 
-    //Server page
-    QWidget *serverConfigureWiget = new QWidget;
-    auto *layout = new QVBoxLayout(serverConfigureWiget);
+    // Server page
+    auto serverConfigureWiget = new QWidget;
+    auto layout = new QVBoxLayout(serverConfigureWiget);
     mServerWidget = new SieveEditorConfigureServerWidget;
     layout->addWidget(mServerWidget);
 
-    mCloseWallet = new QCheckBox(i18n("Close wallet when close application"));
-    layout->addWidget(mCloseWallet);
-
     KPageWidgetItem *serverPageWidgetPage = new KPageWidgetItem(serverConfigureWiget, i18n("Sieve Server"));
     serverPageWidgetPage->setIcon(QIcon::fromTheme(QStringLiteral("network-workgroup")));
     addPage(serverPageWidgetPage);
 
-    //Editor page
-    QWidget *editorWidget = new QWidget;
+    // Editor page
+    auto editorWidget = new QWidget;
     editorWidget->setObjectName(QStringLiteral("editorwidget"));
 
     layout = new QVBoxLayout(editorWidget);
@@ -76,14 +60,14 @@ SieveEditorConfigureDialog::SieveEditorConfigureDialog(QWidget *parent)
     editorPageWidgetPage->setIcon(QIcon::fromTheme(QStringLiteral("accessories-text-editor")));
     addPage(editorPageWidgetPage);
 
-    //UserFeedBack config
+    // UserFeedBack config
 #ifdef WITH_KUSERFEEDBACK
-    QWidget *userFeedBackWidget = new QWidget;
+    auto userFeedBackWidget = new QWidget;
     userFeedBackWidget->setObjectName(QStringLiteral("userFeedBackWidget"));
 
     mUserFeedbackWidget = new KUserFeedback::FeedbackConfigWidget(this);
 
-    auto *userFeedBackLayout = new QHBoxLayout(userFeedBackWidget);
+    auto userFeedBackLayout = new QHBoxLayout(userFeedBackWidget);
     userFeedBackLayout->setContentsMargins({});
     userFeedBackLayout->addWidget(mUserFeedbackWidget);
 
@@ -105,14 +89,12 @@ SieveEditorConfigureDialog::~SieveEditorConfigureDialog()
 void SieveEditorConfigureDialog::loadServerSieveConfig()
 {
     mServerWidget->readConfig();
-    PimCommon::ConfigureImmutableWidgetUtils::loadWidget(mCloseWallet, SieveEditorGlobalConfig::self()->closeWalletItem());
     PimCommon::ConfigureImmutableWidgetUtils::loadWidget(mWrapText, SieveEditorGlobalConfig::self()->wrapTextItem());
 }
 
 void SieveEditorConfigureDialog::saveServerSieveConfig()
 {
     mServerWidget->writeConfig();
-    PimCommon::ConfigureImmutableWidgetUtils::saveCheckBox(mCloseWallet, SieveEditorGlobalConfig::self()->closeWalletItem());
     PimCommon::ConfigureImmutableWidgetUtils::saveCheckBox(mWrapText, SieveEditorGlobalConfig::self()->wrapTextItem());
     SieveEditorGlobalConfig::self()->save();
 #ifdef WITH_KUSERFEEDBACK
