@@ -1,29 +1,15 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SIEVEEDITORMAINWIDGET_H
-#define SIEVEEDITORMAINWIDGET_H
+#pragma once
 
+#include <KSieveUi/ManageSieveWidget>
+#include <KSieveUi/SieveEditorWidget>
 #include <QSplitter>
 #include <QUrl>
-#include <KSieveUi/SieveEditorWidget>
-#include <KSieveUi/ManageSieveWidget>
 class QTabWidget;
 class QStackedWidget;
 class SieveEditorTabWidget;
@@ -113,6 +99,7 @@ private:
     void slotTabCloseRequested(int index);
     void slotTabRemoveAllExclude(int index);
     void slotTabCloseAllRequested();
+
 private:
     void updateStackedWidget();
     QWidget *hasExistingPage(const QUrl &url);
@@ -124,4 +111,3 @@ private:
     SieveEditorEmptyTabWidgetLabel *mEditorEmptyLabel = nullptr;
 };
 
-#endif // SIEVEEDITORMAINWIDGET_H
