@@ -1,32 +1,20 @@
 /*
-   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SIEVEEDITORPAGEWIDGET_H
-#define SIEVEEDITORPAGEWIDGET_H
-#include <QWidget>
-#include <QUrl>
-#include <KSieveUi/SieveEditorWidget>
+#pragma once
 #include <KSieveUi/ManageSieveWidget>
-namespace KManageSieve {
+#include <KSieveUi/SieveEditorWidget>
+#include <QUrl>
+#include <QWidget>
+namespace KManageSieve
+{
 class SieveJob;
 }
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveEditorWidget;
 }
 
@@ -35,7 +23,7 @@ class SieveEditorPageWidget : public QWidget
     Q_OBJECT
 public:
     explicit SieveEditorPageWidget(QWidget *parent = nullptr);
-    ~SieveEditorPageWidget();
+    ~SieveEditorPageWidget() override;
 
     void loadScript(const KSieveUi::ManageSieveWidget::ScriptInfo &info);
     Q_REQUIRED_RESULT QUrl currentUrl() const;
@@ -113,4 +101,3 @@ private:
     bool mIsNewScript = false;
 };
 
-#endif // SIEVEEDITORPAGEWIDGET_H
